@@ -68,9 +68,10 @@ if ( $_GET['updated'] == 'true' ) {
 switch( $_GET['action'] ) {
 	// Edit blog
 	case "editblog":
+		switch_to_blog( $id );
 		$options = $wpdb->get_results( "SELECT * FROM {$wpdb->base_prefix}{$id}_options WHERE option_name NOT LIKE 'rss%' AND option_name NOT LIKE '%user_roles'", ARRAY_A );
 		$details = $wpdb->get_row( "SELECT * FROM {$wpdb->blogs} WHERE blog_id = '{$id}'", ARRAY_A );
-		$editblog_roles = get_blog_option( $id, "{$wpdb->base_prefix}{$id}_user_roles" );
+		$editblog_roles = get_option( "{$wpdb->base_prefix}{$id}_user_roles" );
 		?>
 		<div class="wrap">
 		<h2><?php _e('Edit Blog'); ?> - <a href='http://<?php echo $details['domain'].$details['path']; ?>'>http://<?php echo $details['domain'].$details['path']; ?></a></h2>
@@ -89,7 +90,7 @@ switch( $_GET['action'] ) {
 							<tr class="form-field form-required">
 								<th scope="row"><?php _e('Path') ?></th> 
 								<td><input name="blog[path]" type="text" id="path" value="<?php echo $details['path'] ?>" size="40" style='margin-bottom:5px;' />
-								<br /><input type='checkbox' style='width:20px;' name='update_home_url' value='update' <?php if( get_blog_option( $id, 'siteurl' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) || get_blog_option( $id, 'home' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) ) echo 'checked="checked"'; ?> /> <?php _e( "Update 'siteurl' and 'home' as well." ); ?></td>
+								<br /><input type='checkbox' style='width:20px;' name='update_home_url' value='update' <?php if( get_option( 'siteurl' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) || get_option( 'home' ) == preg_replace('|/+$|', '', 'http://' . $details['domain'] . $details['path']) ) echo 'checked="checked"'; ?> /> <?php _e( "Update 'siteurl' and 'home' as well." ); ?></td>
 							</tr> 
 							<tr class="form-field">
 								<th scope="row"><?php _e('Registered') ?></th> 
@@ -299,6 +300,7 @@ switch( $_GET['action'] ) {
 		</form>
 		</div>
 		<?php
+		restore_current_blog();
 	break;
 
 	// List blogs
@@ -347,11 +349,11 @@ switch( $_GET['action'] ) {
 		$blog_list = $wpdb->get_results( $query, ARRAY_A );
 
 		// Pagination
-		$url2 = "&order=" . $_GET['order'] . "&amp;sortby=" . $_GET['sortby'] . "&amp;s=";
+		$url2 = "&amp;order=" . $_GET['order'] . "&amp;sortby=" . $_GET['sortby'] . "&amp;s=";
 		if( $_GET[ 'blog_ip' ] ) {
-			$url2 .= "&ip_address=" . urlencode( $s );
+			$url2 .= "&amp;ip_address=" . urlencode( $s );
 		} else {
-			$url2 .= $s . "&ip_address=" . urlencode( $s );
+			$url2 .= $s . "&amp;ip_address=" . urlencode( $s );
 		}
 		$blog_navigation = paginate_links( array(
 			'base' => add_query_arg( 'apage', '%#%' ).$url2,
@@ -520,13 +522,18 @@ switch( $_GET['action'] ) {
 								<td valign="top">
 									<?php
 									$blogusers = get_users_of_blog( $blog['blog_id'] ); 
-									if( is_array( $blogusers ) ) {
-										if( $blog['blog_id'] == 1 && count( $blogusers ) > 10 ) {
-											$blogusers = array_slice( $blogusers, 0, 10 );
+									if ( is_array( $blogusers ) ) {
+										$blogusers_warning = '';
+										if ( count( $blogusers ) > 5 ) {
+											$blogusers = array_slice( $blogusers, 0, 5 );
+											$blogusers_warning = __( 'Only showing first 5 users.' ) . ' <a href="http://' . $blog[ 'domain' ] . $blog[ 'path' ] . 'wp-admin/users.php">' . __( 'More' ) . '</a>';
 										}
 										foreach ( $blogusers as $key => $val ) {
 											echo '<a href="user-edit.php?user_id=' . $val->user_id . '">' . $val->user_login . '</a> ('.$val->user_email.')<br />'; 
 										}
+										if( $blogusers_warning != '' ) {
+											echo '<strong>' . $blogusers_warning . '</strong><br />';
+										}
 									}
 									?>
 								</td>
@@ -575,11 +582,13 @@ switch( $_GET['action'] ) {
 					<tr class="form-field form-required">
 						<th style="text-align:center;" scope='row'><?php _e('Blog Address') ?></th>
 						<td>
-						<?php if( constant( "VHOST" ) == 'yes' ) : ?>
-							<input name="blog[domain]" type="text" title="<?php _e('Domain') ?>"/>.<?php echo $current_site->domain;?>
-						<?php else:
+						<?php if ( constant( "VHOST" ) == 'yes' ) { ?>
+							<input name="blog[domain]" type="text" title="<?php _e('Domain') ?>"/>.<?php echo $current_site->domain;?> 
+						<?php } else {
 							echo $current_site->domain . $current_site->path ?><input name="blog[domain]" type="text" title="<?php _e('Domain') ?>"/>
-						<?php endif; ?>
+						<?php } 
+						echo "<p>" . __( 'Only the characters a-z and 0-9 recommended.' ) . "</p>";
+						?>
 						</td>
 					</tr>
 					<tr class="form-field form-required">
